Source Code Documentation
=========================

The source documentation is extracted from the C++ files using Doxygen.

.. toctree::
   :maxdepth: 4

   apidocs/blas1
   apidocs/blas2
   apidocs/blas3
   apidocs/sparse
   apidocs/batched_dense
   apidocs/batched_dense_host
   apidocs/batched_sparse